define(['dashboard-core/js/lib/@waca/dashboard-common/dist/api/ContentActionsProviderAPI'], (ContentActionsProviderAPI) => {
	return class WidgetExport {
		constructor({features}) {
			this._init(features);
		}

		_init(features) {
			this._canvas = features.Canvas;
			this._csvExport = features.CsvExport;
			features.ContentActions.registerProvider('export', this.getAPI());
			this._features = features;
		}
		async exportToCsv(widget) {
			const title = widget.getFeature('Models.internal').getWidgetModel().get('name');
			const dataFeature = widget.getFeature('DataBehindTheVis');
			const data = await dataFeature.getData();
			this._csvExport.export(title, [data.headers], data.cells);
		}

		getAPI() {
			return this;
		}

		_getWidgetContent(idList) {
			let widget = null;
			if (idList.length === 1) {
				const content = this._canvas.getContent(idList[0]);
				const type = content.getType();
				if (type === 'widget.live') {
					const visualization = content.getFeature('Visualization');
					const definition = visualization.getDefinition();
					if (!definition.getProperty('isMultilayersWidget')) {
						widget = content;
					}
				}
			}
			return widget;
		}

		getContentActionList(idList) {
			const actions = [];
			const widget = this._getWidgetContent(idList);
			if (widget) {
				actions.push({
					name: 'export',
					label:  'Export to CSV',
					icon: this._features.Icons.getIcon('arrowDown').id,
					type: 'Button',
					section: ContentActionsProviderAPI.ACTION_SECTION.SELECTION_WIDGET_FORMAT,
					order: 72,
					actions: {
						apply: this.exportToCsv.bind(this, widget)
					}
				});
			}
			return actions;
		}

		destroy() {
			this._canvas = null;
			this._features = null;
		}
	};
});