global.self = {};
global.self['HMR_ContentActionsProviderAPI'] = {
	ACTION_SECTION: {
		SELECTION_WIDGET_FORMAT: 123
	}
}
require('./../../dist/js/WidgetExport');
const WidgetExport = __proxyLoader.WidgetExport['v1/ext/widgetExport/js/WidgetExport'];
const { when } = require('jest-when');

describe('WidgetExport', () => {
	const iconId = 'icon';
	let Canvas, ExportCsv, ContentActions, Icons, features;
	

	beforeEach(() => {
		Canvas = {
		};
		ExportCsv = {
		};
		ContentActions = {
			registerProvider: jest.fn()
		};
		Icons = {
			getIcon: jest.fn().mockReturnValue({
				id: iconId
			})
		};
		features = {
			Canvas,
			ExportCsv,
			ContentActions,
			Icons
		}
	});

	afterEach(() => {
		jest.clearAllMocks();
	});

	it('instantiate', () => {
		const feature = new WidgetExport({features});
		expect(ContentActions.registerProvider).toHaveBeenCalledTimes(1);
		expect(ContentActions.registerProvider).toHaveBeenCalledWith('export', feature);
	});

	it('getContentActionList - no actions when no selection', () => {
		const idList = [];
		const feature = new WidgetExport({features});
		expect(feature.getContentActionList(idList)).toEqual([]);
	});

	it('getContentActionList - no actions when multiple selections', () => {
		const idList = [123, 456];
		const feature = new WidgetExport({features});
		expect(feature.getContentActionList(idList)).toEqual([]);
	});


	it('getContentActionList - no action when single selection is not live widget', () => {
		const content = {
			getType: jest.fn().mockReturnValue('something')
		}
		const idList = ['notLiveWidget'];
		Canvas.getContent = jest.fn();
		when(Canvas.getContent).calledWith(idList[0]).mockReturnValue(content);
		const feature = new WidgetExport({features});
		expect(feature.getContentActionList(idList)).toEqual([]);
	});

	it('getContentActionList - no action when single selection is live widget not supporting show data', () => {
		const definition = {
			getProperty: jest.fn()
		}
		const visualization = {
			getDefinition: jest.fn().mockReturnValue(definition)
		}
		const content = {
			getType: jest.fn().mockReturnValue('widget.live'),
			getFeature: jest.fn()
		}
		when(content.getFeature).calledWith('Visualization').mockReturnValue(visualization);
		when(definition.getProperty).calledWith('isMultilayersWidget').mockReturnValue(true);
		const idList = ['liveWidget'];
		Canvas.getContent = jest.fn();
		when(Canvas.getContent).calledWith(idList[0]).mockReturnValue(content);
		const feature = new WidgetExport({features});
		expect(feature.getContentActionList(idList)).toEqual([]);
	});

	it('getContentActionList - export action when single selection is supported live widget', () => {
		const definition = {
			getProperty: jest.fn()
		}
		const visualization = {
			getDefinition: jest.fn().mockReturnValue(definition)
		}
		const content = {
			getType: jest.fn().mockReturnValue('widget.live'),
			getFeature: jest.fn()
		}
		when(content.getFeature).calledWith('Visualization').mockReturnValue(visualization);
		when(definition.getProperty).calledWith('isMultilayersWidget').mockReturnValue(false);
		const idList = ['liveWidget'];
		Canvas.getContent = jest.fn();
		when(Canvas.getContent).calledWith(idList[0]).mockReturnValue(content);
		const feature = new WidgetExport({features});
		returnedActions = feature.getContentActionList(idList);
		expect(returnedActions.length).toBe(1);
		const action = returnedActions[0];
		expect(action.name).toBe('export');
		expect(action.label).toBe('Export to CSV');
		expect(action.icon).toBe('icon');
		expect(action.type).toBe('Button');
		expect(action.order).toBe(72);
		expect(action.section).toBe(global.self['HMR_ContentActionsProviderAPI'].ACTION_SECTION.SELECTION_WIDGET_FORMAT);
		expect(action.actions.apply).toEqual(expect.any(Function));
		expect(features.Icons.getIcon).toHaveBeenCalledTimes(1);
		expect(features.Icons.getIcon).toHaveBeenCalledWith('arrowDown');
	});



});