export class WidgetExport {
	constructor({features}) {
		this._init(features);
	}

	_init(features) {
		this._canvas = features.Canvas;
		this._csvExport = features.CsvExport;
		features.ContentActions.registerProvider('export', this.getAPI());
		this._features = features;
	}
	async exportToCsv(id) {
		const content = this._canvas.getContent(id);
		const title = content.getFeature('Models.internal').getWidgetModel().get('name');
		const dataFeature = content.getFeature('DataBehindTheVis');
		const data = await dataFeature.getData();
		this._csvExport.export(title, [data.headers], data.cells);
	}

	getAPI() {
		return this;
	}

	getContentActionList(idList) {
		const actions = [];
		if (idList.length === 1) {
			actions.push({
				name: 'export',
				label:  'Export to CSV',
				icon: this._features.Icons.getIcon('arrowDown').id,
				type: 'Button',
				section: 600,
				order: 72,
				actions: {
					apply: this.exportToCsv.bind(this, idList[0])
				}
			});
		}
		return actions;
	}

	destroy() {
		this._canvas = null;
		this._features = null;
	}

}